pub enum WatcherRequest {
Watch {
responder: WatcherWatchResponder,
},
}Expand description
Observer protocol for changes to network interfaces (addition, deletion, and interface property changes).
Variants
Watch
Hanging get for an interface addition/deletion change.
Clients should only have one call of this method at a time; a second call to this method while a call is already pending will cause the server end of the protocol to be closed.
If there are N interfaces present at the time the server end of the
protocol is initialized, then the first N invocations of this method
will return [Event.existing] followed by a single [Event.idle]
indicating that all existing interfaces have been sent. Subsequent calls
will immediately return if there is a change to be reported, or block
until a change occurs.
The server may choose to coalesce property change events, e.g. when multiple independent property changes occur. As a result, clients cannot assume that the order in which they observe the interface changes is the order in which the changes occurred.
- response
eventthe interface change event.
Fields
responder: WatcherWatchResponderImplementations
Sourceimpl WatcherRequest
impl WatcherRequest
pub fn into_watch(self) -> Option<WatcherWatchResponder>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL