pub struct AddressPropertiesInterest(/* private fields */);Implementations
Sourceimpl AddressPropertiesInterest
impl AddressPropertiesInterest
pub const VALID_UNTIL: AddressPropertiesInterest
pub const PREFERRED_LIFETIME_INFO: AddressPropertiesInterest
Sourceimpl AddressPropertiesInterest
impl AddressPropertiesInterest
Sourcepub const fn empty() -> AddressPropertiesInterest
pub const fn empty() -> AddressPropertiesInterest
Get a flags value with all bits unset.
Sourcepub const fn all() -> AddressPropertiesInterest
pub const fn all() -> AddressPropertiesInterest
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<AddressPropertiesInterest>
pub const fn from_bits(bits: u64) -> Option<AddressPropertiesInterest>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> AddressPropertiesInterest
pub const fn from_bits_truncate(bits: u64) -> AddressPropertiesInterest
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> AddressPropertiesInterest
pub const fn from_bits_retain(bits: u64) -> AddressPropertiesInterest
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<AddressPropertiesInterest>
pub fn from_name(name: &str) -> Option<AddressPropertiesInterest>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: AddressPropertiesInterest) -> bool
pub const fn intersects(&self, other: AddressPropertiesInterest) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: AddressPropertiesInterest) -> bool
pub const fn contains(&self, other: AddressPropertiesInterest) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: AddressPropertiesInterest)
pub fn insert(&mut self, other: AddressPropertiesInterest)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: AddressPropertiesInterest)
pub fn remove(&mut self, other: AddressPropertiesInterest)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: AddressPropertiesInterest)
pub fn toggle(&mut self, other: AddressPropertiesInterest)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: AddressPropertiesInterest, value: bool)
pub fn set(&mut self, other: AddressPropertiesInterest, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: AddressPropertiesInterest,
) -> AddressPropertiesInterest
pub const fn intersection( self, other: AddressPropertiesInterest, ) -> AddressPropertiesInterest
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(
self,
other: AddressPropertiesInterest,
) -> AddressPropertiesInterest
pub const fn union( self, other: AddressPropertiesInterest, ) -> AddressPropertiesInterest
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(
self,
other: AddressPropertiesInterest,
) -> AddressPropertiesInterest
pub const fn difference( self, other: AddressPropertiesInterest, ) -> AddressPropertiesInterest
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: AddressPropertiesInterest,
) -> AddressPropertiesInterest
pub const fn symmetric_difference( self, other: AddressPropertiesInterest, ) -> AddressPropertiesInterest
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> AddressPropertiesInterest
pub const fn complement(self) -> AddressPropertiesInterest
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl AddressPropertiesInterest
impl AddressPropertiesInterest
Sourcepub const fn iter(&self) -> Iter<AddressPropertiesInterest>
pub const fn iter(&self) -> Iter<AddressPropertiesInterest>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<AddressPropertiesInterest>
pub const fn iter_names(&self) -> IterNames<AddressPropertiesInterest>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl AddressPropertiesInterest
impl AddressPropertiesInterest
pub fn from_bits_allow_unknown(bits: u64) -> AddressPropertiesInterest
pub fn has_unknown_bits(&self) -> bool
pub fn get_unknown_bits(&self) -> u64